import { HeroBox } from "@components/HeroBox";
import type { INewsCategory } from "@interfaces/INews";
import type { PropsWithChildren } from "react";
import { OverlayTag } from "@components/OverlayTag";
import clsx from "clsx";

export interface HeroSectionProps {
  src: string;
  alt?: string;
  withGradientOnMobile?: boolean;
  title?: string;
  description?: string;
  boxAlignment?: "left" | "right" | "center";
  categories?: INewsCategory[];
  transparentOnMobile?: boolean;
  imageTag?: string;
  className?: string;
  target?: string;
}

export function HeroSection({
  src,
  alt,
  withGradientOnMobile,
  children,
  title,
  description,
  boxAlignment,
  categories,
  transparentOnMobile,
  imageTag,
  className,
  target,
}: PropsWithChildren<HeroSectionProps>) {
  return (
    <section
      role="img"
      aria-label={alt}
      style={{ backgroundImage: `url(${src})` }}
      className={clsx(
        "fs-relative fs-w-full fs-h-[35vh] sm:fs-h-[50vh] md:fs-h-[500px] xl:fs-h-[60vh] xl:fs-pt-12 fs-bg-center fs-bg-no-repeat fs-bg-cover",
        className,
      )}
    >
      {imageTag && (
        <OverlayTag
          text={imageTag}
          className="fs-absolute fs-bottom-0 sm:fs-bottom-6 fs-right-0"
          variant="right"
        />
      )}
      {title && description && (
        <div className="container fs-relative fs-size-full">
          <HeroBox
            title={title}
            description={description}
            categories={categories}
            selfAligned={boxAlignment}
            transparentOnMobile={transparentOnMobile}
            target={target}
          />
        </div>
      )}
      {children}
      {withGradientOnMobile && (
        <div className="fs-block lg:fs-hidden fs-absolute fs-bottom-0 fs-z-10 fs-w-full fs-h-1/2 fs-bg-gradient-to-b fs-from-transparent fs-to-[#313846]"></div>
      )}
    </section>
  );
}
