import { Button } from "@components/Button";
import { Email } from "@carbon/icons-react";

import type { StoryDefault, Story } from "@ladle/react";

interface ButtonConfigProps {
  text: string;
  type: "primary" | "secondary" | "tertiary";
  disabled: boolean;
  size: "xs" | "sm" | "md" | "lg" | "xl";
}

export const ButtonStory: Story<ButtonConfigProps> = ({
  type,
  disabled,
  size,
  text,
}: ButtonConfigProps) => (
  <div className="fs-grid fs-grid-cols-3 fs-gap-5">
    <div>
      <h2>Default</h2>
      <Button text={text} type={type} size={size} disabled={disabled} />
    </div>

    <div>
      <h2>Default with Icon</h2>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        icon={<Email />}
      />
    </div>

    <div>
      <h2>Default with Icon right</h2>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        icon={<Email />}
        iconRight
      />
    </div>

    <div>
      <h2>Rounded</h2>
      <Button text={text} type={type} size={size} disabled={disabled} rounded />
    </div>

    <div>
      <h2>Rounded with Icon</h2>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        rounded
        icon={<Email />}
      />
    </div>

    <div>
      <h2>Rounded with Icon right</h2>
      <Button
        text={text}
        type={type}
        size={size}
        disabled={disabled}
        rounded
        icon={<Email />}
        iconRight
      />
    </div>

    <div>
      <h2>Circular (Icon only)</h2>
      <Button
        type={type}
        size={size}
        disabled={disabled}
        circular
        icon={<Email />}
      />
    </div>
  </div>
);

ButtonStory.args = {
  text: "Button",
  disabled: false,
};
ButtonStory.argTypes = {
  type: {
    options: ["primary", "secondary", "tertiary"],
    control: { type: "radio" },
    defaultValue: "primary",
  },
  size: {
    options: ["xs", "sm", "md", "lg", "xl"],
    control: { type: "radio" },
    defaultValue: "md",
  },
};
export default {
  title: "Atoms",
} satisfies StoryDefault;

ButtonStory.storyName = "Button";
ButtonStory.meta = {
  descriptionTitle: "Button",
  description:
    "This is a button component, which offers three visual color styles (primary, secondary, tertiary), five differente sizes (xs-xl) and two boolean visual modifiers (rounded and circular). It can also render a Link instead of a button. It can be decorated with an Icon on either side of the button caption.",
};
