import { HeroBox } from "@components/HeroBox";
import { HeroSection } from "@components/HeroSection";
import type { Story, StoryDefault } from "@ladle/react";

interface HeroBoxConfigProps {
  title: string;
  description: string;
  selfAligned: "left" | "right" | "center";
  transparentOnMobile: boolean;
  target?: string;
  categories?: string[];
}

export const HeroBoxStory: Story<HeroBoxConfigProps> = ({
  title,
  description,
  selfAligned,
  transparentOnMobile,
  target,
  categories,
}: HeroBoxConfigProps) => (
  <HeroSection
    src="https://picsum.photos/id/1015/1600/900"
    withGradientOnMobile={transparentOnMobile}
    imageTag="@Copyright"
  >
    <HeroBox
      title={title}
      description={description}
      categories={categories?.map((category, i) => ({
        id: i,
        title: category,
        href: "/",
      }))}
      selfAligned={selfAligned}
      transparentOnMobile={transparentOnMobile}
      target={target}
    />
  </HeroSection>
);

HeroBoxStory.args = {
  title: "Alles auf einer Karte: Die Hamburger Maker-Map",
  description:
    "Finde Fab Labs, offene Werkstätten, Handwerksbetriebe, Bildungs- und Veranstaltungsorte",
  transparentOnMobile: true,
  target: "https://www.google.com",
  categories: ["Fab City", "Makerspace"],
};

HeroBoxStory.argTypes = {
  selfAligned: {
    options: ["left", "right", "center"],
    control: { type: "radio" },
    defaultValue: "left",
  },
};

export default {
  title: "Molecules",
} satisfies StoryDefault;

HeroBoxStory.storyName = "Hero Box";
HeroBoxStory.meta = {
  descriptionTitle: "Hero Box",
  description:
    "A Hero Box is used inside of a Hero Section. It shows a colored box with a title, subtitle and tags/categories. It offers different alignment options to be placed inside of a Hero section.",
};
