import { HorizontalNewsCard } from "@components/HorizontalNewsCard";
import type { Story, StoryDefault } from "@ladle/react";
import { Color } from "@interfaces/INews";

interface HorizontalNewsCardConfigProps {
  customBackgroundColor: Color;
  textColor: "dark" | "light";
  title: string;
  description: string;
  href: string;
  image: string;
  imageAlt: string;
  category: string;
  date: string;
  location: string;
  variant?: "light" | "dark" | "undefined";
}

export const HorizontalNewsCardStory: Story<HorizontalNewsCardConfigProps> = ({
  customBackgroundColor,
  textColor,
  title,
  description,
  href,
  image,
  imageAlt,
  category,
  date,
  location,
  variant,
}: HorizontalNewsCardConfigProps) => {
  return (
    <div className="fs-w-full fs-max-w-[800px]">
      {variant !== "undefined" ? (
        <HorizontalNewsCard
          image={{ alt: imageAlt, src: image }}
          title={title}
          description={description}
          date={date}
          location={location}
          category={{
            id: 1,
            title: category,
            href: "/",
          }}
          href={href}
          variant={variant}
        />
      ) : (
        <HorizontalNewsCard
          image={{ alt: imageAlt, src: image }}
          title={title}
          description={description}
          date={date}
          location={location}
          category={{
            id: 1,
            title: category,
            href: "/",
          }}
          href={href}
          customBackgroundColor={customBackgroundColor}
          textColor={textColor}
        />
      )}
    </div>
  );
};

HorizontalNewsCardStory.args = {
  customBackgroundColor: "#fcba03",
  image: "https://picsum.photos/id/103/600/600",
  imageAlt: "Some description of the image",
  href: "https://google.de",
  title: "Lorem ipsum dolor sit amet consectetur adipiscing",
  description:
    "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque nunc lectus, lobortis ut justo et, tempus fermentum purus",
  date: "",
  location: "",
  category: "Fab City",
};

HorizontalNewsCardStory.argTypes = {
  textColor: {
    options: ["dark", "light"],
    control: { type: "radio" },
    defaultValue: "dark",
  },
  variant: {
    options: ["dark", "light", undefined],
    control: { type: "radio" },
    defaultValue: "dark",
  },
};

export default {
  title: "Molecules",
} satisfies StoryDefault;

HorizontalNewsCardStory.storyName = "Horizontal News Card";
HorizontalNewsCardStory.meta = {
  descriptionTitle: "Horizontal News Card",
  description:
    "A News card that has a horizontal orientation. Similar to the 'Vertical News Card'. Instead of a description, it can also show a location and date with appropriate icons.",
};
