import { Header } from "@components/Header/Header";
import { HeroSection } from "@components/HeroSection";
import type { Story } from "@ladle/react";
import {
  ChoroplethMap,
  Folders,
  Chat,
  Calendar,
  ApplicationVirtual,
  Email,
  UserAvatar,
  Notification,
} from "@carbon/icons-react";
import { ITopBarItem, IToolbarItem } from "@interfaces/IHeader";
import { useState } from "react";
import { Article } from "@components/Article";
import { AccordionItem } from "@components/AccordionItem";
import { ActionBox } from "@components/ActionBox";
import { Feature } from "@components/Feature";
import { Tabs, Tab } from "@components/Tabs";
import { Grid } from "@components/Grid";
import { Button } from "@components/Button";
import { NEWS, TABLE_OF_CONTENTS } from "@common/constants";

const TOPBAR_ITEMS: ITopBarItem[] = [
  {
    title: "Fab City Hamburg",
    target: "/",
    children: [
      {
        title: "FCHH Association",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
          {
            title: "L3 Item 5",
            target: "/",
          },
        ],
      },
      {
        title: "Hamburg 2054",
        target: "/",
      },
      {
        title: "Members",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "Career",
        target: "/",
      },
      {
        title: "Blog",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
    ],
  },
  {
    title: "Network",
    target: "/",
    children: [
      {
        title: "Map",
        target: "/",
      },
      {
        title: "Fab Labs",
        target: "/",
      },
      {
        title: "Unternehmen",
        target: "/",
      },
      {
        title: "Community",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "Fab City Global",
        target: "/",
      },
    ],
  },
  {
    title: "Projects",
    target: "/",
    children: [
      {
        title: "Kalender",
        target: "/",
      },
      {
        title: "Workshops",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "Prototype Session",
        target: "/",
      },
      {
        title: "Fab Friday",
        target: "/",
      },
      {
        title: "Maker Challenge 2022",
        target: "/",
      },
    ],
  },
  {
    title: "Research",
    target: "/",
    children: [
      {
        title: "Fab City OS",
        target: "/",
      },
      {
        title: "Open Lab Starter Kit",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
        ],
      },
      {
        title: "FarmBot Hamburg",
        target: "/",
        children: [
          {
            title: "L3 Item 1",
            target: "/",
          },
          {
            title: "L3 Item 2",
            target: "/",
          },
          {
            title: "L3 Item 3",
            target: "/",
          },
          {
            title: "L3 Item 4",
            target: "/",
          },
          {
            title: "L3 Item 5",
            target: "/",
          },
        ],
      },
      {
        title: "Fab City Incubator",
        target: "/",
      },
      {
        title: "Fab City Index",
        target: "/",
      },
    ],
  },
  {
    title: "Contact",
    target: "/",
  },
];

const itemClasses = "fs-size-6 sm:fs-size-5 sm:fs-mr-2 fs-mb-1 sm:fs-mb-0";

const TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Map",
    icon: <ChoroplethMap className={itemClasses} />,
    href: "/map",
  },
  {
    title: "Knowledge Hub",
    icon: <Folders className={itemClasses} />,
    href: "/hub",
    onlyDesktop: true,
  },
  {
    title: "Connect",
    icon: <Chat className={itemClasses} />,
    href: "/connect",
  },
  {
    title: "Events",
    icon: <Calendar className={itemClasses} />,
    href: "/events",
  },
  {
    title: "FCOS Core",
    icon: <ApplicationVirtual className={itemClasses} />,
    href: "/map",
  },
];

const EXTENDED_TOOLBAR_ITEMS: IToolbarItem[] = [
  {
    title: "Email",
    icon: <Email size={24} />,
    href: "/email",
  },
  {
    title: "Notification",
    icon: <Notification size={24} />,
    href: "/notification",
  },
  {
    title: "User",
    icon: <UserAvatar size={24} />,
    href: "/user",
  },
];

const DATA = {
  title: "Alles auf einer Karte: Die Hamburger Maker-Map",
  description:
    "Finde Fab Labs, offene Werkstätten, Handwerksbetriebe, Bildungs- und Veranstaltungsorte",
  categories: [
    {
      id: 1,
      title: "Fab City HH",
      href: "/",
    },
    {
      id: 2,
      title: "Makerspaces",
      href: "/",
    },
  ],
};

const HtmlContent: React.FC = () => {
  return (
    <>
      <h2>File-based routing</h2>
      <p>
        Astro leverages a routing strategy called{" "}
        <strong>file-based routing.</strong> Every <code>.astro</code> file in
        your <code>src/pages</code> directory becomes a page or an endpoint on
        your site based on its file path. Write standard HTML{" "}
        <a href="https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a">
          <code>&lt;a&gt;</code> elements
        </a>{" "}
        in your component template to link between pages.
      </p>
      <blockquote>
        Famous quote goes in here. Lorem ipsum dolor sit amet, consetetur
        sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et
        dolore magna aliquyam erat, sed diam voluptua.
      </blockquote>
      <h3>Page HTML</h3>
      <p>
        Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy
        eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam
        voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet
        clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit
        amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam
        nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
        sed diam voluptua. At vero eos et accusam et justo duo dolores et ea
        rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem
        ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing
        elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna
        aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo
        dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus
        est Lorem ipsum dolor sit amet. Here comes a list:
      </p>
      <ul>
        <li>First item</li>
        <li>Second item</li>
        <li>Third item</li>
      </ul>
      <AccordionItem className="fs-not-prose" title="Closed accordion">
        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed
        metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus
        est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet
        velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus
        purus varius a. In hac habitasse platea dictumst. Quisque in lobortis
        tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum,
        id cursus orci blandit. Maecenas semper urna sit amet viverra interdum.
      </AccordionItem>
      <AccordionItem className="fs-not-prose" open title="Opened accordion">
        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed
        metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus
        est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet
        velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus
        purus varius a. In hac habitasse platea dictumst. Quisque in lobortis
        tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum,
        id cursus orci blandit. Maecenas semper urna sit amet viverra interdum.
      </AccordionItem>
      <p>
        Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy
        eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam
        voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet
        clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit
        amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam
        nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
        sed diam voluptua. At vero eos et accusam et justo duo dolores et ea
        rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem
        ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing
        elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna
        aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo
        dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus
        est Lorem ipsum dolor sit amet.
      </p>
      <ActionBox
        className="fs-not-prose"
        title="Fab Friday"
        description="Open knowledge Exchange, weekly from 5–6 pm"
      >
        <Button
          text="Join Fab Friday"
          type="primary"
          onClick={() => console.log("Join Fab Friday")}
        />
        <Button text="Learn more" type="tertiary" href="/" />
      </ActionBox>
      <h3>Leveraging Page Layouts</h3>
      <p>
        Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy
        eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam
        voluptua. At vero eos et accusam et justo duo dolores et ea rebum. Stet
        clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit
        amet. Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam
        nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
        sed diam voluptua. At vero eos et accusam et justo duo dolores et ea
        rebum. Stet clita kasd gubergren, no sea takimata sanctus est Lorem
        ipsum dolor sit amet. Lorem ipsum dolor sit amet, consetetur sadipscing
        elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna
        aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo
        dolores et ea rebum. Stet clita kasd gubergren, no sea takimata sanctus
        est Lorem ipsum dolor sit amet.
      </p>

      <Grid columns={2}>
        <Feature
          className="fs-not-prose"
          title="With Link"
          description="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus purus varius a. In hac habitasse platea dictumst. Quisque in lobortis tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum, id cursus orci blandit. Maecenas semper urna sit amet viverra interdum."
          icon="chat"
          href="http://www.google.de"
        />
        <Feature
          className="fs-not-prose"
          title="Without Link"
          description="Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam egestas sed metus nec molestie. Proin mattis ligula vel eros rhoncus, vel dapibus est sollicitudin. Phasellus quis velit diam. Suspendisse a aliquet velit. Etiam vel accumsan enim. Sed scelerisque leo purus, id luctus purus varius a. In hac habitasse platea dictumst. Quisque in lobortis tortor. Sed eu pellentesque sem. Duis sagittis leo at nunc condimentum, id cursus orci blandit. Maecenas semper urna sit amet viverra interdum."
          icon="wikis"
        />
      </Grid>

      <h2>Markdown Pages</h2>
      <p>
        Astro also treats any Markdown (<code>.md</code>) files inside of{" "}
        <code>/src/pages/</code> as pages in your final website. These are
        commonly used for text-heavy pages like blog posts and documentation.
      </p>
      <Tabs className="fs-not-prose">
        <Tab label="My account">
          Id orci tellus laoreet id ac. Dolor, aenean leo, ac etiam consequat
          in. Convallis arcu ipsum urna nibh. Pharetra, euismod vitae interdum
          mauris enim, consequat vulputate nibh. Maecenas pellentesque id sed
          tellus mauris, ultrices mauris. Tincidunt enim cursus ridiculus mi.
          Pellentesque nam sed nullam sed diam turpis ipsum eu a sed convallis
          diam.
        </Tab>
        <Tab label="Company">
          Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum
          dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit
          amet, consectetur adipiscing elit.
        </Tab>
        <Tab label="Team Members">
          Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum
          dolor sit amet, consectetur adipiscing elit.
        </Tab>
        <Tab label="Billing">
          Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum
          dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit
          amet, consectetur adipiscing elit.
        </Tab>
      </Tabs>
      <p>
        Page layouts are especially useful for{" "}
        <a href="#markdown-pages">Markdown files.</a> Markdown files can use the
        special <code>layout</code> front matter property to specify a{" "}
        <a href="/en/core-concepts/layouts/">layout component</a> that will wrap
        their Markdown content in a full{" "}
        <code>&lt;html&gt;...&lt;/html&gt;</code> page document.
      </p>

      <Button text={"Just a button"} type={"primary"} size="lg" />

      <h3>H3 Interhead Two Lorem Ipsum</h3>
      <p>
        Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse
        molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero
        eros et accumsan et iusto odio dignissim qui blandit praesent luptatum
        zzril delenit augue duis dolore te feugait nulla facilisi. Lorem ipsum
        dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh
        euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi
        enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit
        lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum
        iriure dolor in hendrerit in vulputate velit esse molestie consequat,
        vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et
        iusto odio dignissim qui blandit praesent luptatum zzril delenit augue
        duis dolore te feugait nulla facilisi.
      </p>
    </>
  );
};

const BREADCRUMBS = [
  { title: "My Top Page" },
  { title: "Subpage", target: "/home/subpage" },
  { title: "Sub Sub Page", target: "/home/subpage" },
];

interface StartpageConfigProps {
  itemsAlwaysLight: boolean;
  title: string;
  description: string;
  selfAligned: "left" | "right" | "center";
  transparentOnMobile: boolean;
  target?: string;
}

/* eslint-disable react/prop-types */
export const Startpage: Story<StartpageConfigProps> = ({
  itemsAlwaysLight,
  title,
  description,
  transparentOnMobile,
  target,
}) => {
  const languages = ["de", "en"];
  const [selectedLanguage, setSelectedLanguage] = useState(languages[0]);
  return (
    <>
      <HeroSection
        src="https://picsum.photos/id/1015/1600/900"
        withGradientOnMobile={transparentOnMobile}
        imageTag="@Copyright"
        title={title}
        description={description}
        categories={DATA.categories}
        transparentOnMobile={transparentOnMobile}
        target={target}
      >
        <Header
          topBarItems={TOPBAR_ITEMS}
          toolBarItems={TOOLBAR_ITEMS}
          extendedToolBarItems={EXTENDED_TOOLBAR_ITEMS}
          languages={languages}
          selectedLanguage={selectedLanguage}
          onChangeLanguage={(newLanguage) => {
            console.log("New language selected: ", newLanguage);
            setSelectedLanguage(newLanguage);
          }}
          onSearch={(keyword) => console.log("Search for: ", keyword)}
          itemsAlwaysLight={itemsAlwaysLight}
        />
      </HeroSection>
      <Article
        teaser={
          "Pages are a special type of Astro component that live in the src/pages/ subdirectory. They are responsible for handling routing, data loading, and overall page layout for every HTML page in your website. This paragraph is a lead paragraph."
        }
        breadcrumbs={BREADCRUMBS}
        title="Here comes a very interesting article title"
        subtitle="Hey here goes the subtitle"
        tableOfContents={TABLE_OF_CONTENTS}
        relatedContent={NEWS}
        tags={[{ title: "Category 1", target: "#section1" }]}
        dateAndAuthor={"May 13, 2022 | Author Name, Author Name"}
      >
        <HtmlContent />
      </Article>
    </>
  );
};

Startpage.args = {
  itemsAlwaysLight: false,
  title: "Alles auf einer Karte: Die Hamburger Maker-Map",
  description:
    "Finde Fab Labs, offene Werkstätten, Handwerksbetriebe, Bildungs- und Veranstaltungsorte",
  transparentOnMobile: true,
  target: "https://www.google.com",
};

Startpage.argTypes = {
  selfAligned: {
    options: ["left", "right", "center"],
    control: { type: "radio" },
    defaultValue: "left",
  },
};

export default {
  title: "Organisms",
};

Startpage.storyName = "Startpage";
