import * as path from "path";
import { defineConfig } from "vite";
import react from "@vitejs/plugin-react";
import dts from "vite-plugin-dts";
import { devDependencies } from "./package.json";

export default defineConfig({
  plugins: [
    react(),
    dts({
      insertTypesEntry: true,
    }),
  ],
  resolve: {
    alias: {
      "@components/*": path.join(__dirname, "src/components/*"),
      "@components": path.join(__dirname, "src/components"),
      "@styles/*": path.join(__dirname, "src/assets/styles/*"),
      "@styles": path.join(__dirname, "src/assets/styles"),
      "@interfaces/*": path.join(__dirname, "src/interfaces/*"),
      "@interfaces": path.join(__dirname, "src/interfaces"),
      "@assets/*": path.join(__dirname, "src/assets/*"),
      "@assets": path.join(__dirname, "src/assets"),
      "@core/*": path.join(__dirname, "src/core/*"),
      "@core": path.join(__dirname, "src/core"),
      "@layouts/*": path.join(__dirname, "src/layouts/*"),
      "@layouts": path.join(__dirname, "src/layouts"),
      "@pages/*": path.join(__dirname, "src/pages/*"),
      "@pages": path.join(__dirname, "src/pages"),
      "@common/*": path.join(__dirname, "src/common/*"),
      "@common": path.join(__dirname, "src/common"),
      "@hooks/*": path.join(__dirname, "src/hooks/*"),
      "@hooks": path.join(__dirname, "src/hooks"),
      "@contexts/*": path.join(__dirname, "src/contexts/*"),
      "@contexts": path.join(__dirname, "src/contexts"),
      "@utils/*": path.join(__dirname, "src/utils/*"),
      "@utils": path.join(__dirname, "src/utils"),
    },
  },
  build: {
    lib: {
      entry: path.resolve(__dirname, "src/index.tsx"),
      name: "@fchh/fcos-suite-ui",
      fileName: "fcos-suite-ui",
      formats: ["es"],
    },
    rollupOptions: {
      external: [...Object.keys(devDependencies), "react", "react/jsx-runtime"],
      output: {
        globals: {
          react: "React",
          "react-dom": "ReactDOM",
        },
      },
    },
  },
});
